# This file was auto-generated by Fern from our API Definition.

import typing

from .chat_message_content_item import ChatMessageContentItem

Content = typing.Union[str, typing.List[ChatMessageContentItem]]
