# This file was auto-generated by Fern from our API Definition.

import typing

from .function_choice import FunctionChoice

CreateChatCompletionStreamRequestToolChoice = typing.Union[
    typing.Literal["auto"], typing.Literal["required"], FunctionChoice
]
